@@ -53,14 +53,14 @@ def build_CVs(CV_list, parmed_structure, system):
             # add the atoms or groups to the force
             group_list = []
             for receiver_group in cv[1]:
-                group_list.append(wd_force.addGroup([receiver_group]))
+                group_list.append(wd_force.addGroup([int(i) for i in receiver_group]))
             for donor_group in cv[2]:
-                group_list.append(wd_force.addGroup([donor_group]))
+                group_list.append(wd_force.addGroup([int(i) for i in donor_group]))
 
             # add the params weight and initial distance holders
             for i in range(len(cv[1])):
                 wd_force.addPerBondParameter('w{}'.format(i))
-                wd_force.addPerBondParameter('r{}'.format(i))
+                # wd_force.addPerBondParameter('r{}'.format(i))
 
             # find param values
             masses = []
@@ -71,9 +71,9 @@ def build_CVs(CV_list, parmed_structure, system):
             param_list = []
             for i in range(len(cv[1])):
                 param_list.append(weights[i])
-                param_list.append(
-                    dist(parmed_structure.coordinates[cv[1][i]] / 10,
-                         parmed_structure.coordinates[cv[2][i]] / 10))
+                # param_list.append(
+                #     dist(parmed_structure.coordinates[cv[1][i]] / 10,
+                #          parmed_structure.coordinates[cv[2][i]] / 10))
 
             # add the bond to the force with params
             wd_force.addBond(group_list, param_list)
@@ -90,12 +90,12 @@ def build_CVs(CV_list, parmed_structure, system):
             # specifying the receptor groups and the cv[2] is a list of donor groups
 
             if not isinstance(cv[1], list):
-                raise ValueError("""coordination number only accepts a list of lists where the CN will depend on a combination of 
+                raise ValueError("""coordination number only accepts a list where the CN will depend on a combination of 
             distances specified pairwise by the atoms in the two lists. So first cv[1] is a list of atom groups
             specifying the receptor groups and the cv[2] is a list of donor groups""")
 
             if not isinstance(cv[2], list):
-                raise ValueError("""coordination number only accepts a list of lists where the CN will depend on a combination of 
+                raise ValueError("""coordination number only accepts a list where the CN will depend on a combination of 
             distances specified pairwise by the atoms in the two lists. So first cv[1] is a list of atom groups
             specifying the receptor groups and the cv[2] is a list of donor groups""")
 
@@ -103,7 +103,13 @@ def build_CVs(CV_list, parmed_structure, system):
                 raise ValueError('Donor and Acceptor lists must be the same length')
 
             if len(cv[1]) != len(cv[6]):
-                raise ValueError('number of weights must be the same as the number of groups of atoms')
+                raise ValueError('number of weights must be the same as the number of atoms in donor/receiver groups')
+
+            if len(cv[1]) != len(cv[7]):
+                raise ValueError('number of decay lengths must be the same as number of atoms in donor/receiver list')
+
+            if len(cv[1]) != len(cv[8]):
+                raise ValueError('number of initial distances must be the same as number of atoms in donor/receiver list')
 
             # build CV force string in lepton syntax
             k = 1
@@ -123,9 +129,10 @@ def build_CVs(CV_list, parmed_structure, system):
             # add the atoms or groups to the force
             group_list = []
             for receiver_group in cv[1]:
-                group_list.append(cn_force.addGroup([receiver_group]))
+                print('adding {} to cn_force'.format(receiver_group))
+                group_list.append(cn_force.addGroup([int(i) for i in receiver_group]))
             for donor_group in cv[2]:
-                group_list.append(cn_force.addGroup([donor_group]))
+                group_list.append(cn_force.addGroup([int(i) for i in donor_group]))
 
             # add the params weight and initial distance holders
             for i in range(len(cv[1])):
@@ -134,17 +141,14 @@ def build_CVs(CV_list, parmed_structure, system):
                 cn_force.addPerBondParameter('d{}'.format(i))
 
             weights = cv[6]
+            initial_distances = cv[8]
             decay_lengths = cv[7]
             param_list = []
             for i in range(len(cv[1])):
                 param_list.append(weights[i])
-                # coordinates are stored in Angstroms, everything else in nm
-                r0 = dist(parmed_structure.coordinates[cv[1][i]],
-                          parmed_structure.coordinates[cv[2][i]]) / 10
-                print('r0', r0)
-                param_list.append(r0)
+                param_list.append(initial_distances[i])
                 param_list.append(decay_lengths[i])
-            print(param_list)
+            print('building CN equation with following param list',param_list)
 
             # add the bond to the force with params
             cn_force.addBond(group_list, param_list)
