@@ -1118,7 +1118,7 @@ class MetadynamicSimulation(MDSimulation):
         self.bias_frequency = int(bias_frequency / self.step_length)
         self.bias_directory = bias_directory
         self.bias_save_frequency = int(bias_save_frequency / self.step_length)
-        self.fes_interval = int(fes_interval / self.step_length)
+        self.fes_interval = fes_interval
         self.dome = dome
         self.funnel = funnel
         self.radius_scale_factor = radius_scale_factor
@@ -1269,7 +1269,7 @@ class MetadynamicSimulation(MDSimulation):
 
 
         if fes_interval is None:
-            fes_steps = round(self.fes_interval)
+            fes_steps = int(round(self.fes_interval / self.step_length))
         else:
             fes_steps = int(round(fes_interval / self.step_length))
 
