@@ -311,6 +311,7 @@ class SegmentMappingSim(MetadynamicSimulation):
 
         if self.run_scans_bool:
             self.run_scans()
+
         if self.run_production_bool:
             self.run_production()
         else:
@@ -334,8 +335,8 @@ class SegmentMappingSim(MetadynamicSimulation):
 class SegmentMappingSimHREMD(SegmentMappingSim):
 
     def __init__(self, max_production_time=200 * unit.nanosecond, min_production_time = 5 * unit.nanosecond,
-                 swap_freq = 2 * unit.nanosecond,
-                 convergence_window=2 * unit.nanosecond, dG_displacement_criteria = 1, min_coverage_criteria=.25,
+                 swap_freq = 2 * unit.nanosecond, convergence_window=2 * unit.nanosecond,
+                 dG_displacement_criteria = 1, min_coverage_criteria=.25,
                  **kwargs):
         self.min_production_time = min_production_time
         self.max_production_time = max_production_time
@@ -368,7 +369,6 @@ class SegmentMappingSimHREMD(SegmentMappingSim):
 
         #get total num steps for reporters
         nsteps = int(self.max_production_time / self.step_length)
-        print('nsteps for production phase',nsteps)
         self.simulation.reporters = []
         self._add_reporters(total_steps = nsteps + self.simulation.currentStep)
         #once again we fix the FES Reporter freq to ensure convergence detection works
@@ -389,9 +389,10 @@ class SegmentMappingSimHREMD(SegmentMappingSim):
         sim_time=0 * unit.nanosecond
         accepted = 0
         attempted = 0
-        continue_simulating=True
         dG_std = 100
         dG_displacement = 100
+        continue_simulating=True
+
         while continue_simulating:
 
             #run the sim
@@ -430,12 +431,11 @@ class SegmentMappingSimHREMD(SegmentMappingSim):
                 dG_trace = pickle.load(handle)
 
             #get the rolling average dG displacement and variance of the production dG value trace over a limited range
-            # dG_trace is written every .01 * ns / step_length steps
-            window_steps = int(int(self.convergence_window / self.step_length)/int(self.fes_interval/self.step_length))
+            window_steps = np.max([1,int(int(self.convergence_window / self.step_length)/int(self.fes_interval/self.step_length))])
             # print('window steps, len(dG-trace)',window_steps,len(dG_trace))
 
             if len(dG_trace)>window_steps:
-                window_trace = dG_trace[:-window_steps]
+                window_trace = dG_trace[len(dG_trace)-window_steps:]
                 dG_std = np.std(window_trace)
                 print('dG_std over the last {}: {}'.format(self.convergence_window,dG_std))
                 m_ave = moving_average(window_trace, np.max([1,int(len(window_trace)/3)]))
